Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2135)

Unified Diff: runtime/vm/dart_api_impl.h

Issue 411633002: Fix for issue 19817 (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 6 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/bootstrap.cc ('k') | runtime/vm/dart_api_impl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/dart_api_impl.h
===================================================================
--- runtime/vm/dart_api_impl.h (revision 38470)
+++ runtime/vm/dart_api_impl.h (working copy)
@@ -142,9 +142,10 @@
static const Instance& UnwrapInstanceHandle(
const ReusableObjectHandleScope& reused, Dart_Handle object);
// Returns an Error handle if isolate is in an inconsistent state.
// Returns a Success handle when no error condition exists.
- static Dart_Handle CheckIsolateState(Isolate *isolate);
+ static Dart_Handle CheckAndFinalizePendingClasses(Isolate *isolate);
// Casts the internal Isolate* type to the external Dart_Isolate type.
static Dart_Isolate CastIsolate(Isolate* isolate);
« no previous file with comments | « runtime/vm/bootstrap.cc ('k') | runtime/vm/dart_api_impl.cc » ('j') | no next file with comments »
@@ -142,9 +142,10 @@
static const Instance& UnwrapInstanceHandle(
const ReusableObjectHandleScope& reused, Dart_Handle object);
- // Returns an Error handle if isolate is in an inconsistent state.
+ // Returns an Error handle if isolate is in an inconsistent state
+ // or there was an error while finalizing classes.
// Returns a Success handle when no error condition exists.

Powered by Google App Engine
This is Rietveld 408576698